@@ -147,7 +147,6 @@ def get_submission_generators(n, sub, allsub, use_psaw):
     if use_psaw:
         recent, prev = get_submission_psaw(n, sub_dict)
 
-        print("Searching for tickers...")
         current_scores, current_rocket_scores = get_ticker_scores_psaw(recent)
         prev_scores, prev_rocket_scores = get_ticker_scores_psaw(prev)
     else:
@@ -159,7 +158,6 @@ def get_submission_generators(n, sub, allsub, use_psaw):
             print(sub)
             print("try switching to psaw")
         else: 
-            print("Searching for tickers...")
             current_scores, current_rocket_scores = get_ticker_scores_praw(recent)
             prev_scores, prev_rocket_scores = get_ticker_scores_praw(prev)  
 
@@ -507,7 +505,7 @@ def print_df(df, filename, writecsv, api):
     print("Wrote to file successfully: ")
     print(completeName)
 
-def main(imported=False):
+def acquire(imported=False):
     import argparse
     import json
     import pandas as pd
@@ -537,7 +535,7 @@ def main(imported=False):
                     help='Sort the results table by descending order of score, 1 = sort by total score, 2 = sort by recent score, 3 = sort by previous score, 4 = sort by change in score, 5 = sort by # of rocket emojis')
 
     parser.add_argument('--allsub', default=True, action='store_true',
-                    help='Using this parameter searchs from one subreddit only, default subreddit is r/pennystocks.')
+                    help='Using this parameter searchs from all subreddits.')
 
     parser.add_argument('--psaw', default=False, action='store_true',
                     help='Using this parameter selects psaw (push-shift) as the reddit scraper over praw (reddit-api)')
